pub fn reset_all_settings() -> Result<(), ConfigError>Expand description
Deletes the config.json file and clears the secrets from the OS keyring.
pub fn reset_all_settings() -> Result<(), ConfigError>Deletes the config.json file and clears the secrets from the OS keyring.