Shared scan_library task trigger and wait helpers (CLI + TUI).
Structs
- Scan
Library Options - Options for starting a library scan and optionally blocking until it finishes.
- Scan
Library Start
Enums
- Scan
Cache Invalidate - After a successful scan wait, optionally drop stale entries from the on-disk ROM list cache.
Constants
Functions
- apply_
disk_ cache_ invalidate - Drop stale on-disk ROM list cache entries after a successful scan.
- start_
scan_ library - POST
scan_librarywith optional task kwargs (e.g.{"platform_slugs":["gba"]}). - wait_
for_ task_ terminal - Poll
GET /api/tasks/{task_id}every 2 seconds until terminal state or timeout.on_statusis invoked with each non-terminal status string (may be empty on parse miss). On success returns the last status JSON (typicallystatus==finished).